"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const mz_1 = require("mz");
const path = require("path");
const TEMPLATE_FILE_PATH = path.join(__dirname, '..', 'generator', 'template.js');
class Generate extends command_1.Command {
    async run() {
        const { flags } = this.parse(Generate);
        let fileName = flags.fileName || 'template.js';
        // add file extension if needed
        if (!/\.js$/.test(fileName))
            fileName = `${fileName}.js`;
        // copy our template to the CWD
        const templateFile = await mz_1.fs.readFile(TEMPLATE_FILE_PATH);
        const OUTPUT_FILE_PATH = path.join(process.cwd(), fileName);
        try {
            // write the file if it doesn't exist
            await mz_1.fs.writeFile(OUTPUT_FILE_PATH, templateFile, { flag: 'wx' });
            this.log(`Generated template file at ${OUTPUT_FILE_PATH}`);
        }
        catch (err) {
            if (err.code === 'EEXIST') {
                this.error(`${OUTPUT_FILE_PATH} already exists. Use a different filename or delete the file`);
            }
            else {
                throw err;
            }
        }
    }
}
Generate.description = 'generate a new mail merge template in the current working directory';
Generate.flags = {
    help: command_1.flags.help({ char: 'h' }),
    fileName: command_1.flags.string({ char: 'f', description: 'the output filename', default: 'template.js' }),
};
exports.default = Generate;
