"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const inquirer = require("inquirer");
const mz_1 = require("mz");
const path = require("path");
class Credentials extends command_1.Command {
    async run() {
        const { configDir } = this.config;
        const responses = await inquirer.prompt([
            {
                name: 'liveKey',
                message: 'Mandrill live key',
                type: 'input',
                validate: input => input.length > 0
            },
            {
                name: 'testKey',
                message: 'Mandrill test key',
                type: 'input',
                validate: input => input.length > 0
            }
        ]);
        // build the environment file
        const config = {
            mandrill: {
                liveKey: responses.liveKey,
                testKey: responses.testKey
            }
        };
        // save to the users homeDir
        try {
            await mz_1.fs.mkdir(configDir);
        }
        catch (err) {
            if (err.code !== 'EEXIST')
                throw err;
        }
        await mz_1.fs.writeFile(path.join(configDir, 'config.json'), JSON.stringify(config));
    }
}
Credentials.description = 'add or remove Mandrill credentials';
Credentials.flags = {
    help: command_1.flags.help({ char: 'h' })
};
exports.default = Credentials;
